CStrNonNull

Struct CStrNonNull 

pub struct CStrNonNull<'s> { /* private fields */ }
Option<CStrNonNull> is ABI compatible with *const c_char.

If you want to treat null() as "", use CStrPtr instead.

Implementations

Source

impl<'s> CStrNonNull<'s>

pub unsafe fn from_ptr_unchecked_unbounded(ptr: *const c_char) -> Self

Convert a raw C-string into a CStrPtr. Note that the lifetime of the returned reference is unbounded!

Safety
  • ptr cannot be null
  • ptr must point to a \0-terminated C string
  • The underlying C-string cannot change for the duration of the lifetime 's.
  • The lifetime 's is unbounded by this fn. Very easy to accidentally extend. Be careful!
pub fn from_bytes_with_nul( bytes: &'s [u8], ) -> Result<Self, FromBytesWithNulError>

Convert a raw slice of bytes into a CStrNonNull. bytes should end with \0, but contain no interior \0s otherwise.

pub unsafe fn from_bytes_with_nul_unchecked(bytes: &'s [u8]) -> Self

Convert a raw slice of bytes to a CStrNonNull. The resulting string will be terminated at the first \0 in bytes.

Safety
  • bytes must contain at least one \0.
pub fn as_ptr(&self) -> *const c_char

Treat self as a raw C string.

pub fn as_non_null(&self) -> NonNull<c_char>

Treat self as a NonNull C string.

pub fn is_empty(&self) -> bool

Checks if self is empty (either null(), or the first character is \0.)

pub fn to_bytes(&self) -> &'s [u8]

Convert self to a &[u8] slice, excluding the terminal \0.

O(n) to find the terminal \0.

pub fn to_bytes_with_nul(&self) -> &'s [u8]

Convert self to a &[u8] slice, including the terminal \0.

O(n) to find the terminal \0.

pub fn to_cstr(&self) -> &'s CStr

Convert self to a std::ffi::CStr.

O(n) to find the terminal \0.

pub fn to_str(&self) -> Result<&'s str, Utf8Error>

Convert self to a &str.

O(n) to find the terminal \0 and validate UTF8.

pub fn to_string_lossy(&self) -> Cow<'s, str>

Convert self to a Cow<str>.

O(n) to find the terminal \0 and validate, and to convert UTF8ish data to UTF8 if necesssary.