pub struct CStrNonNull<'s> { /* private fields */ }Expand description
Option<CStrNonNull> is ABI compatible with *const c_char.
Implementations
Sourceimpl<'s> CStrNonNull<'s>
impl<'s> CStrNonNull<'s>
Sourcepub unsafe fn from_ptr_unchecked_unbounded(ptr: *const c_char) -> Self
pub unsafe fn from_ptr_unchecked_unbounded(ptr: *const c_char) -> Self
Convert a raw C-string into a CStrPtr. Note that the lifetime of the returned reference is unbounded!
Safety
ptrcannot be nullptrmust point to a\0-terminated C string- The underlying C-string cannot change for the duration of the lifetime
's. - The lifetime
'sis unbounded by this fn. Very easy to accidentally extend. Be careful!
Sourcepub fn from_bytes_with_nul(
bytes: &'s [u8],
) -> Result<Self, FromBytesWithNulError>
pub fn from_bytes_with_nul( bytes: &'s [u8], ) -> Result<Self, FromBytesWithNulError>
Convert a raw slice of bytes into a CStrNonNull. bytes should end with \0, but contain no interior \0s otherwise.
Sourcepub unsafe fn from_bytes_with_nul_unchecked(bytes: &'s [u8]) -> Self
pub unsafe fn from_bytes_with_nul_unchecked(bytes: &'s [u8]) -> Self
Convert a raw slice of bytes to a CStrNonNull. The resulting string will be terminated at the first \0 in bytes.
Safety
bytesmust contain at least one\0.
Sourcepub fn as_non_null(&self) -> NonNull<c_char>
pub fn as_non_null(&self) -> NonNull<c_char>
Treat self as a NonNull C string.
Sourcepub fn is_empty(&self) -> bool
pub fn is_empty(&self) -> bool
Checks if self is empty (either null(), or the first character is \0.)
Sourcepub fn to_bytes(&self) -> &'s [u8] ⓘ
pub fn to_bytes(&self) -> &'s [u8] ⓘ
Convert self to a &[u8] slice, excluding the terminal \0.
O(n) to find the terminal \0.
Sourcepub fn to_bytes_with_nul(&self) -> &'s [u8] ⓘ
pub fn to_bytes_with_nul(&self) -> &'s [u8] ⓘ
Convert self to a &[u8] slice, including the terminal \0.
O(n) to find the terminal \0.
Sourcepub fn to_cstr(&self) -> &'s CStr
pub fn to_cstr(&self) -> &'s CStr
Convert self to a std::ffi::CStr.
O(n) to find the terminal \0.